@@ -20,16 +20,18 @@ from gamornet.keras_module import check_input_shape_validity, check_imgs_validit
 def get_model_from_link_tflearn(base_link, file_names, model):
 
     # Skipping over random name generation because the tflearn files themselves are named in a super specific way
-    # Thus there is no chance of accidental deletion like the keras model.h5 names
+    # Thus there is no chance of accidental deletion like the keras model.h5
+    # names
 
-    file_links = np.core.defchararray.add(np.array([base_link]*3), file_names)
+    file_links = np.core.defchararray.add(
+        np.array([base_link] * 3), file_names)
 
     for link in file_links:
         wget.download(link)
 
     try:
         model.load(file_names[2][:-5])
-    except:
+    except BaseException:
         os.remove(file_names[0])
         os.remove(file_names[1])
         os.remove(file_names[2])
@@ -85,7 +87,8 @@ def gamornet_load_model_tflearn(model, model_load_path):
 ############################################
 ##########TFLEARN FUNCTIONS##################
 
-def gamornet_build_model_tflearn(input_shape, trainable_bools=[True]*8, load_layers_bools=[True]*8):
+def gamornet_build_model_tflearn(input_shape, trainable_bools=[
+                                 True] * 8, load_layers_bools=[True] * 8):
 
     input_shape = check_input_shape_validity(input_shape)
     load_layers_bools = check_bools_validity(load_layers_bools)
@@ -121,49 +124,50 @@ def gamornet_build_model_tflearn(input_shape, trainable_bools=[True]*8, load_lay
     return model
 
 
-def gamornet_predict_tflearn(img_array, model_load_path, input_shape, batch_size=64, individual_arrays=False, trainable_bools=[True]*8, 
+def gamornet_predict_tflearn(img_array, model_load_path, input_shape, batch_size=64, individual_arrays=False, trainable_bools=[True] * 8,
                              clear_session=False):
-
     """
-    Uses a `tflearn` model to perform predictions on supplied images. 
+    Uses a TFLearn model to perform predictions on supplied images.
 
     Parameters
     ----------
     img_array: Numpy ndarray[nsamples, x, y, ndim]
-        The array of images on which the predictions are to be performed. We insist on numpy arrays as many of the 
-        underlying deep learning frameworks work better with numpy arrays compared to other array-like elements. 
+        The array of images on which the predictions are to be performed. We insist on numpy arrays as many of the
+        underlying deep learning frameworks work better with numpy arrays compared to other array-like elements.
 
-    model_load_path: str 
-        Path to the saved model. Note that tflearn models are usually consist of three files in the format file_name.``data``,
-        file_name.``info``, file_name.``meta``. For this parameter, simply specify file_path/file_name.
-        
-        This parameter can take the following special values
+    model_load_path: str
+        Path to the saved model. Note that tflearn models usually consist of three files in the format ``file_name.data``,
+        ``file_name.index``, ``file_name.meta``. For this parameter, simply specify file_path/file_name.
 
-        * ``SDSS_sim`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations a z~0 from Ghosh et. al. (2020)
+        This parameter can also take the following special values
+
+        * ``SDSS_sim`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations at z~0 from Ghosh et. al. (2020)
         * ``SDSS_tl`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations and real data at z~0 from Ghosh et. al. (2020)
-        * ``CANDELS_sim`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations a z~1 from Ghosh et. al. (2020)
+        * ``CANDELS_sim`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations at z~1 from Ghosh et. al. (2020)
         * ``CANDELS_tl`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations and real data at z~1 from Ghosh et. al. (2020)
 
     input_shape: tuple of ints (x, y, ndim) or allowed str
-        The shape of the images being used. The parameter can also take the following special values:-
+        The shape of the images being used in the form of a tuple. 
+
+        This parameter can also take the following special values:-
 
         * ``SDSS`` - Sets the input shape to be (167,167,1) as was used for the SDSS g-band images in Ghosh et. al. (2020)
         * ``CANDELS`` -  Sets the input shape to be (83,83,1) as was used for the CANDELS H-band images in Ghosh et. al. (2020)
 
     batch_size: int
         This variable specifies how many images will be processed in a single batch. Set this value to lower than the default
-        if you have limited memory availability. This doesn't affect the predictions in any way. 
+        if you have limited memory availability. This doesn't affect the predictions in any way.
 
     individual_arrays: bool
-        If set to True, this will unpack the three returned arrays 
+        If set to True, this will unpack the three returned arrays
 
     trainable_bools: array of bools or allowed str
-        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet were 
+        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet were
         set to trainable during the training phase of the model (which is now being used for prediction)
 
-        The orders of the bools correspond to the Following Layer numbers [2,5,8,9,10,13,15,17] in GaMorNet. Please see 
-        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details The first five layers are the convolutional
-        layers and the last three are the fully connected layers.  
+        The order of the bools correspond to the following layer numbers [2, 5, 8, 9, 10, 13, 15, 17] in GaMorNet. Please see
+        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details. The first five layers are the convolutional
+        layers and the last three are the fully connected layers.
 
         This parameter can also take the following special values which are handy when you are using our models to
         perform predictions:-
@@ -172,26 +176,26 @@ def gamornet_predict_tflearn(img_array, model_load_path, input_shape, batch_size
         * ``train_bools_CANDELS``- Sets the bools according to what was done for the CANDELS data in Ghosh et. al. (2020)
 
     clear_session: bool
-        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a 
-        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuses the same layer names 
+        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a
+        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuse the same layer names
         leading to conflicts)
 
-        Note that, if set to True, you will lose access to any other graphs you may have run before. 
+        Note that if set to True, you will lose access to any other graphs you may have run before.
 
 
     Returns
     -------
     predicted probabilities: array_like
-        The returned array consists of the probability for each galaxy to be disk-dominated, indeterminate and bulge-dominated 
-        respectively [disk_prob,indet_prob,bulge_prob].If individual arrays are set to True, the single array is unpacked 
-        and returned  as three separate arrays in the same order. 
-
-        The ordering of individual elements in this array corresponds to the array of images fed in. 
+        The returned array consists of the probability for each galaxy to be disk-dominated, indeterminate and bulge-dominated
+        respectively [disk_prob, indet_prob, bulge_prob]. If ``individual_arrays`` is set to ``True``, the single array is unpacked and returned
+        as three separate arrays in the same order.
 
+        The ordering of individual elements in this array corresponds to the array of images fed in.
 
     """
 
-    # TFLearn Loads graphs from memory by name, hence it's always advisable to set this to True if using in a Notebook.
+    # TFLearn Loads graphs from memory by name, hence it's always advisable to
+    # set this to True if using in a Notebook.
     if clear_session is True:
         K.clear_session()
 
@@ -209,22 +213,20 @@ def gamornet_predict_tflearn(img_array, model_load_path, input_shape, batch_size
     preds = []  # array to store results
 
     total_elements = len(img_array)
-    num_batches = int(total_elements/batch_size)
+    num_batches = int(total_elements / batch_size)
 
     # Time to Flush all Print Statements before the progressbar output comes on
     time.sleep(0.3)
 
-
     for i in progressbar.progressbar(range(0, num_batches)):
-        ll = i*batch_size
-        ul = (i+1)*batch_size
+        ll = i * batch_size
+        ul = (i + 1) * batch_size
         preds.extend(model.predict(img_array[ll:ul]))
 
-    
-    if num_batches == 0: #when batch_size > number of images
+    if num_batches == 0:  # when batch_size > number of images
         preds.extend(model.predict(img_array[0:len(img_array)]))
 
-    elif ul != len(img_array):# for the last partial batch
+    elif ul != len(img_array):  # for the last partial batch
         preds.extend(model.predict(img_array[ul:len(img_array)]))
 
     preds = np.array(preds)  # converting to a numpy array for easier handling.
@@ -236,24 +238,22 @@ def gamornet_predict_tflearn(img_array, model_load_path, input_shape, batch_size
         return preds
 
 
-def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, validation_labels, input_shape, files_save_path="./", epochs=100, 
-                           max_checkpoints=1, batch_size=64, lr=0.0001, momentum=0.9, decay=0.0, nesterov=False, loss='categorical_crossentropy', 
+def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, validation_labels, input_shape, files_save_path="./", epochs=100,
+                           max_checkpoints=1, batch_size=64, lr=0.0001, momentum=0.9, decay=0.0, nesterov=False, loss='categorical_crossentropy',
                            load_model=False, model_load_path="./", save_model=True, show_metric=True, clear_session=False):
-
-
     """
-    Trains and return a GaMorNet model using TFLearn. 
+    Trains and return a GaMorNet model using TFLearn.
 
     Parameters
     -----------
 
     training_imgs: Numpy ndarray [nsamples,x,y,ndim]
-        The array of images on which are to be used for the training process. We insist on numpy arrays 
-        as many of the underlying deep learning frameworks work better with numpy arrays compared to 
+        The array of images which are to be used for the training process. We insist on numpy arrays
+        as many of the underlying deep learning frameworks work better with numpy arrays compared to
         other array-like elements.
 
     training_labels: Numpy ndarray [nsamples,label_arrays]
-        The truth labels for each of the training images. The supplied labels must be in the one-hot encoding 
+        The truth labels for each of the training images. The supplied labels must be in the one-hot encoding
         format. We reproduce below what each individual label array should look like:-
 
         * Disk-dominated - ``[1,0,0]``
@@ -261,12 +261,12 @@ def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, vali
         * Bulge-dominated - ``[0,0,1]``
 
     validation_imgs: Numpy ndarray [nsamples,x,y,ndim]
-        The array of images on which are to be used for the validation process. We insist on numpy arrays 
-        as many of the underlying deep learning frameworks work better with numpy arrays compared to 
+        The array of images which are to be used for the validation process. We insist on numpy arrays
+        as many of the underlying deep learning frameworks work better with numpy arrays compared to
         other array-like elements.
 
     validation_labels: Numpy ndarray [nsamples,label_arrays]
-        The truth labels for each of the validation images. The supplied labels must be in the one-hot encoding 
+        The truth labels for each of the validation images. The supplied labels must be in the one-hot encoding
         format. We reproduce below what each individual label array should look like:-
 
         * Disk-dominated - ``[1,0,0]``
@@ -274,79 +274,81 @@ def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, vali
         * Bulge-dominated - ``[0,0,1]``
 
     input_shape: tuple of ints (x, y, ndim) or allowed str
-        The shape of the images being used. The parameter can also take the following special values:-
+        The shape of the images being used in the form of a tuple. 
+
+        This parameter can also take the following special values:-
 
         * ``SDSS`` - Sets the input shape to be (167,167,1) as was used for the SDSS g-band images in Ghosh et. al. (2020)
         * ``CANDELS`` -  Sets the input shape to be (83,83,1) as was used for the CANDELS H-band images in Ghosh et. al. (2020)
 
     files_save_path: str
-        The full path to the location where the model generated during the training process are to be 
+        The full path to the location where the models generated during the training process are to be
         saved. The path should end with the name of the file. For eg. ``/path/checkpoint``. This
-        will result in model files of the form ``checkpoint.meta", ``checkpoint.data`` and
-        ``checkpoint.info`` being saved. 
+        will result in model files of the form ``checkpoint.meta``, ``checkpoint.data`` and
+        ``checkpoint.index`` being saved.
 
-        Set this to `/dev/null` on a unix system if you don't want to save the file(s)
+        Set this to ``/dev/null`` on a unix system if you don't want to save the file(s)
 
     epochs: int
-        The number of epochs for which you want to training the model. 
+        The number of epochs for which you want to train the model.
 
     max_checkpoints: int
-        TFLearn saves the model at the end of each epoch. This parameter controls how many of the 
-        most recent models are saved. For eg. setting this to 2, will save the model state during the 
-        most recent two epochs. 
+        TFLearn saves the model at the end of each epoch. This parameter controls how many of the
+        most recent models are saved. For eg. setting this to 2, will save the model state during the
+        most recent two epochs.
 
     batch_size: int
-        This variable specifies how many images will be processed in a single batch. This is a 
+        This variable specifies how many images will be processed in a single batch. This is a
         hyperparameter. The default value is a good starting point
 
     lr: float
-        This is the learning rate to be used during the training process. This is a 
+        This is the learning rate to be used during the training process. This is a
         hyperparameter that should be tuned during the training process. The default value is a good
         starting point.
 
     momentum: float
-        The value momentum to be used in the gradient descent optimizer that is used to train GaMorNet. 
-        This must always be :math:`\geq 0`. This accelerates the gradient descent process. This is a 
-        hyperparameter. The default value is a good starting point. 
+        The value of the momentum to be used in the gradient descent optimizer that is used to train GaMorNet.
+        This must always be :math:`\geq 0`. This accelerates the gradient descent process. This is a
+        hyperparameter. The default value is a good starting point.
 
     decay: float
-        The amount of learning rate decay to be applied over each update. 
+        The amount of learning rate decay to be applied over each update.
 
     nesterov: bool
-        Whether to apply Nesterov momentum or not. 
+        Whether to apply Nesterov momentum or not.
 
     loss: allowed str or function
-        The loss function to be used. If using the string option, you need to supply the name of 
+        The loss function to be used. If using the string option, you need to specify the name of
         the loss function. This can be set to be any loss available in ``tflearn``
 
     load_model: bool
-        Whether you want to start the training from a previously saved model. 
+        Whether you want to start the training from a previously saved model.
 
-        We strongly recommend using the ``gamornet_tl_keras`` function for more 
+        We strongly recommend using the ``gamornet_tl_tflearn`` function for more
         control over the process when starting the training from a previously
         saved model.
 
     model_load_path: str
-        Required `iff load_model ==True`. The path to the saved model.
+        Required iff ``load_model == True``. The path to the saved model.
 
-        Note that tflearn models are usually consist of three files in the format 
-        file_name.``data``, file_name.``info``, file_name.``meta``. For this parameter,
+        Note that tflearn models usually consist of three files in the format
+        ``file_name.data``, ``file_name.index``, ``file_name.meta``. For this parameter,
         simply specify file_path/file_name.
 
     save_model: bool
         Whether you want to save the model files at each epoch during training. This
         parameter should be used in conjunction with  ``max_checkpoints`` to configure
-        how many of the saved model files are preserved till the end. 
+        how many of the saved model files are preserved till the end.
 
     show_metric: bool
         Whether to display the training/testing metrics during training.
 
     clear_session: bool
-        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a 
-        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuses the same layer names 
+        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a
+        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuse the same layer names
         leading to conflicts)
 
-        Note that, if set to True, you will lose access to any other graphs you may have run before. 
+        Note that if set to True, you will lose access to any other graphs you may have run before.
 
 
     Returns
@@ -356,8 +358,8 @@ def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, vali
 
     """
 
-
-    # TFLearn Loads graphs from memory by name, hence it's always advisable to set this to True if using in a Notebook.
+    # TFLearn Loads graphs from memory by name, hence it's always advisable to
+    # set this to True if using in a Notebook.
     if clear_session is True:
         K.clear_session()
 
@@ -387,24 +389,23 @@ def gamornet_train_tflearn(training_imgs, training_labels, validation_imgs, vali
     return model
 
 
-def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validation_labels, input_shape, load_layers_bools=[True]*8, 
-                        trainable_bools=[True]*8, model_load_path="./", files_save_path="./", epochs=100, max_checkpoints=1, batch_size=64, 
-                        lr=0.00001, momentum=0.9, decay=0.0, nesterov=False, loss='categorical_crossentropy', save_model=True, 
+def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validation_labels, input_shape, load_layers_bools=[True] * 8,
+                        trainable_bools=[True] * 8, model_load_path="./", files_save_path="./", epochs=100, max_checkpoints=1, batch_size=64,
+                        lr=0.00001, momentum=0.9, decay=0.0, nesterov=False, loss='categorical_crossentropy', save_model=True,
                         show_metric=True, clear_session=False):
-
     """
-    Performs Transfer Learning (TL) using a previously trained GaMorNet model. 
+    Performs Transfer Learning (TL) using a previously trained GaMorNet model.
 
     Parameters
     -----------
 
     training_imgs: Numpy ndarray [nsamples,x,y,ndim]
-        The array of images on which are to be used for the TL process. We insist on numpy arrays 
-        as many of the underlying deep learning frameworks work better with numpy arrays compared to 
+        The array of images which are to be used for the TL process. We insist on numpy arrays
+        as many of the underlying deep learning frameworks work better with numpy arrays compared to
         other array-like elements.
 
     training_labels: Numpy ndarray [nsamples,label_arrays]
-        The truth labels for each of the TL images. The supplied labels must be in the one-hot encoding 
+        The truth labels for each of the TL images. The supplied labels must be in the one-hot encoding
         format. We reproduce below what each individual label array should look like:-
 
         * Disk-dominated - ``[1,0,0]``
@@ -412,12 +413,12 @@ def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validat
         * Bulge-dominated - ``[0,0,1]``
 
     validation_imgs: Numpy ndarray [nsamples,x,y,ndim]
-        The array of images on which are to be used for the validation process. We insist on numpy arrays 
-        as many of the underlying deep learning frameworks work better with numpy arrays compared to 
+        The array of images which are to be used for the validation process. We insist on numpy arrays
+        as many of the underlying deep learning frameworks work better with numpy arrays compared to
         other array-like elements.
 
     validation_labels: Numpy ndarray [nsamples,label_arrays]
-        The truth labels for each of the validation images. The supplied labels must be in the one-hot encoding 
+        The truth labels for each of the validation images. The supplied labels must be in the one-hot encoding
         format. We reproduce below what each individual label array should look like:-
 
         * Disk-dominated - ``[1,0,0]``
@@ -425,19 +426,21 @@ def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validat
         * Bulge-dominated - ``[0,0,1]``
 
     input_shape: tuple of ints (x, y, ndim) or allowed str
-        The shape of the images being used. The parameter can also take the following special values:-
+        The shape of the images being used in the form of a tuple. 
+
+        This parameter can also take the following special values:-
 
         * ``SDSS`` - Sets the input shape to be (167,167,1) as was used for the SDSS g-band images in Ghosh et. al. (2020)
         * ``CANDELS`` -  Sets the input shape to be (83,83,1) as was used for the CANDELS H-band images in Ghosh et. al. (2020)
 
     load_layers_bools: array of bools
-        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet will be 
+        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet will be
         loaded during the transfer learning process from the supplied starting model. The rest of the layers will be
         initialized from scratch.
 
-        The orders of the bools correspond to the Following Layer numbers [2,5,8,9,10,13,15,17] in GaMorNet. Please see 
-        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details The first five layers are the convolutional
-        layers and the last three are the fully connected layers.  
+        The order of the bools correspond to the following layer numbers [2, 5, 8, 9, 10, 13, 15, 17] in GaMorNet. Please see
+        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details. The first five layers are the convolutional
+        layers and the last three are the fully connected layers.
 
         This parameter can also take the following special values which are handy when you are using our models to
         perform predictions:-
@@ -446,13 +449,13 @@ def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validat
         * ``load_bools_CANDELS``- Sets the bools according to what was done for the CANDELS data in Ghosh et. al. (2020)
 
     trainable_bools: array of bools
-        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet will be 
+        This variable is used to identify which of the 5 convolutional and 3 fully-connected layers of GaMorNet will be
         trainable during the transfer learning process. The rest are frozen at the values loaded from the previous
         model.
 
-        The orders of the bools correspond to the Following Layer numbers [2,5,8,9,10,13,15,17] in GaMorNet. Please see 
-        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details The first five layers are the convolutional
-        layers and the last three are the fully connected layers.  
+        The order of the bools correspond to the following layer numbers [2, 5, 8, 9, 10, 13, 15, 17] in GaMorNet. Please see
+        Figure 4 and Table 2 of Ghosh et. al. (2020) to get more details. The first five layers are the convolutional
+        layers and the last three are the fully connected layers.
 
         This parameter can also take the following special values which are handy when you are using our models to
         perform predictions:-
@@ -461,81 +464,82 @@ def gamornet_tl_tflearn(training_imgs, training_labels, validation_imgs, validat
         * ``train_bools_CANDELS``- Sets the bools according to what was done for the CANDELS data in Ghosh et. al. (2020)
 
     model_load_path: str
-        Path to the saved model, which will serve as the starting point for transfer learning. Note that 
-        tflearn models are usually consist of three files in the format file_name.``data``,
-        file_name.``info``, file_name.``meta``. For this parameter, simply specify file_path/file_name.
+        Path to the saved model, which will serve as the starting point for transfer learning. Note that
+        tflearn models usually consist of three files in the format ``file_name.data``,
+        ``file_name.index``, ``file_name.meta``. For this parameter, simply specify file_path/file_name.
 
         This parameter can also take the following special values
-        
-        * ``SDSS_sim`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations a z~0 from Ghosh et. al. (2020)
+
+        * ``SDSS_sim`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations at z~0 from Ghosh et. al. (2020)
         * ``SDSS_tl`` -- Downloads and uses GaMorNet models trained on SDSS g-band simulations and real data at z~0 from Ghosh et. al. (2020)
-        * ``CANDELS_sim`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations a z~1 from Ghosh et. al. (2020)
+        * ``CANDELS_sim`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations at z~1 from Ghosh et. al. (2020)
         * ``CANDELS_tl`` -- Downloads and uses GaMorNet models trained on CANDELS H-band simulations and real data at z~1 from Ghosh et. al. (2020)
 
     files_save_path: str
-        The full path to the location where the model generated during the training process are to be 
+        The full path to the location where the models generated during the training process are to be
         saved. The path should end with the name of the file. For eg. ``/path/checkpoint``. This
-        will result in model files of the form ``checkpoint.meta", ``checkpoint.data`` and
-        ``checkpoint.info`` being saved. 
+        will result in model files of the form ``checkpoint.meta``, ``checkpoint.data`` and
+        ``checkpoint.index`` being saved.
 
-        Set this to `/dev/null` on a unix system if you don't want to save the output. 
+        Set this to ``/dev/null`` on a unix system if you don't want to save the output.
 
     epochs: int
-        The number of epochs for which you want to training the model. 
+        The number of epochs for which you want to train the model.
 
     max_checkpoints: int
-        TFLearn saves the model at the end of each epoch. This parameter controls how many of the 
-        most recent models are saved. For eg. setting this to 2, will save the model state during the 
+        TFLearn saves the model at the end of each epoch. This parameter controls how many of the
+        most recent models are saved. For eg. setting this to 2, will save the model state during the
         most recent two epochs.
 
     batch_size: int
-        This variable specifies how many images will be processed in a single batch. This is a 
+        This variable specifies how many images will be processed in a single batch. This is a
         hyperparameter. The default value is a good starting point
 
     lr: float
-        This is the learning rate to be used during the training process. This is a 
+        This is the learning rate to be used during the training process. This is a
         hyperparameter that should be tuned during the training process. The default value is a good
         starting point.
 
     momentum: float
-        The value momentum to be used in the gradient descent optimizer that is used to train GaMorNet. 
-        This must always be :math:`\geq 0`. This accelerates the gradient descent process. This is a 
-        hyperparameter. The default value is a good starting point. 
+        The value of the momentum to be used in the gradient descent optimizer that is used to train GaMorNet.
+        This must always be :math:`\geq 0`. This accelerates the gradient descent process. This is a
+        hyperparameter. The default value is a good starting point.
 
     decay: float
-        The amount of learning rate decay to be applied over each update. 
+        The amount of learning rate decay to be applied over each update.
 
     nesterov: bool
-        Whether to apply Nesterov momentum or not. 
+        Whether to apply Nesterov momentum or not.
 
     loss: allowed str or function
-        The loss function to be used. If using the string option, you need to supply the name of 
+        The loss function to be used. If using the string option, you need to specify the name of
         the loss function. This can be set to be any loss available in ``tflearn``
 
     save_model: bool
         Whether you want to save the model files at each epoch during training. This
         parameter should be used in conjunction with  ``max_checkpoints`` to configure
-        how many of the saved model files are preserved till the end. 
+        how many of the saved model files are preserved till the end.
 
     show_metric: bool
         Whether to display the training/testing metrics during training.
 
     clear_session: bool
-        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a 
-        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuses the same layer names 
+        If set to True, this will clear the TensorFlow session currently running. This is handy while running GaMorNet in a
+        notebook to avoid variable name confusions. (Sometimes, under the hood, TFLearn & Tensorflow reuse the same layer names
         leading to conflicts)
 
-        Note that, if set to True, you will lose access to any other graphs you may have run before. 
+        Note that if set to True, you will lose access to any other graphs you may have run before.
 
 
     Returns
     --------
 
     Trained TFLearn Model: TFLearn ``models.dnn.DNN`` class
-        
+
     """
 
-    # TFLearn Loads graphs from memory by name, hence it's always advisable to set this to True if using in a Notebook.
+    # TFLearn Loads graphs from memory by name, hence it's always advisable to
+    # set this to True if using in a Notebook.
     if clear_session is True:
         K.clear_session()
 
